
# Type: end interbase coordinate




URI: [biolink:end_interbase_coordinate](https://w3id.org/biolink/vocab/end_interbase_coordinate)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents

 *  is_a: [interbase coordinate](interbase_coordinate.md)

## Children


## Used by

 * [GenomicSequenceLocalization](GenomicSequenceLocalization.md)
